Calculates the co, and further described in following publication ...
[clinmon: An R package for calculation of clinical monitoring indices (2019)]
Co - https ://www.ncbi.nlm.nih.gov/ pmc / articles /PMC5317099/
CO (EST) = PP / (SBP+DBP) * HR
Data imported with 2 columns: time (in seconds), physiological measurement (raw measurement).
del_1
Deleter periods for pressure with two columns, first column is start of deletion period and last column is end of deletion period, every row is a deletion period. (dataframe)
del_2
Deleter periods for pressure with two columns, first column is start of deletion period and last column is end of deletion period, every row is a deletion period. (dataframe)
trigger
Trigger periods with two columns, first column is start of analysed period and last column is end of analysed period, every row is a period for analysis. (dataframe)
blocksize
Size of blocks created in seconds, default is 3 s. (numeric)
freq
Frequency of recorded data, default is 1000 Hz. (numeric)
blockmin
Minimum measurements ratio in every block, default is 0.5 (numeric)
output
select the resolution of output, either 'period' or 'block' (boolian)
Value
Returns a dataframe with the results, with either every period or block as a rows, depending on the chosen output