powered by
Calculates the pulsatility index, and further described in following publication ... [clinmon: An R package for calculation of clinical monitoring indices (2020)]
PI(df, del = NULL, trigger = NULL, blocksize = 3, freq, blockmin = 0.5, output = 'period')
Raw recording with data in 2 columns: time (in seconds) and pressure/velocity curve measurement (e.g. ABP, raw measurement). [dataframe]
Deleter with two columns: (1) start of deletion period and (2) end of deletion period. Every row is a deletion period. [dataframe]
Trigger with two columns: (1) start of analysed period and (2) end of analysed period. Every row is a period for analysis. [dataframe]
Size of blocks, in seconds. [numeric]
Frequency of recorded data, in Hz. [numeric]
Minimum measurements required to create a block [numeric]
Select the output which has to be either one row per 'period' or 'block'. [boolian]
Returns a dataframe with the results, with either every period or block as a rows, depending on the chosen output
# NOT RUN { data <- data.frame(time=seq(1, 901, 0.01), pres=rnorm(90001)) PI(df=data, freq=100) # }
Run the code above in your browser using DataLab