Learn R Programming

clinmon (version 0.2.0)

RI: Resistance index (RI)

Description

Calculates the resistance index, and further described in following publication ... [clinmon: An R package for calculation of clinical monitoring indices (2020)]

Usage

RI(df, del = NULL, trigger = NULL,
      blocksize = 3, freq, blockmin = 0.5,
      output = "period")

Arguments

df

Raw recording with data in 2 columns: time (in seconds) and CBFv measurement (e.g. MCAv, raw measurement). [dataframe]

del

Deleter with two columns: (1) start of deletion period and (2) end of deletion period. Every row is a deletion period. [dataframe]

trigger

Trigger with two columns: (1) start of analysed period and (2) end of analysed period. Every row is a period for analysis. [dataframe]

blocksize

Size of blocks, in seconds. [numeric]

freq

Frequency of recorded data, in Hz. [numeric]

blockmin

Minimum measurements required to create a block [numeric]

output

Select the output which has to be either one row per 'period' or 'block'. [boolian]

Value

Returns a dataframe with the results, with either every period or block as a rows, depending on the chosen output

Examples

Run this code
# NOT RUN {
  data <- data.frame(time=seq(1, 901, 0.01),
                      pres=rnorm(90001))
  RI(df=data, freq=100)
# }

Run the code above in your browser using DataLab