Learn R Programming

clinmon (version 0.2.0)

Sx: Systolic flow velocity index (Sx)

Description

Calculates Sx, and further described in following publication ... [clinmon: An R package for calculation of clinical monitoring indices (2020)]

Usage

Sx(df, del_1 = NULL, del_2 = NULL,
      trigger = NULL, blocksize = 3,
      epochsize = 20, freq, blockmin = 0.5,
      epochmin = 0.5, overlapping = FALSE,
      output = 'period')

Arguments

df

Raw recording with data in 3 columns: time (in seconds), pressure curve measurement (e.g. CPP, raw measurement), and velocity curve measurement (e.g. MCAv, raw measurement). [dataframe]

del_1

Deleter with two columns, reference to pressure curve measurement: (1) start of deletion period and (2) end of deletion period. Every row is a deletion period. [dataframe]

del_2

Deleter with two columns, reference to velocity curve measurement: (1) start of deletion period and (2) end of deletion period. Every row is a deletion period. [dataframe]

trigger

Trigger with two columns: (1) start of analysed period and (2) end of analysed period. Every row is a period for analysis. [dataframe]

blocksize

Size of blocks, in seconds. [numeric]

epochsize

Size of epochs, in number of blocks. [numeric]

freq

Frequency of recorded data, in Hz. [numeric]

blockmin

Minimum measurements required to create a block [numeric]

epochmin

Minimum blocks required to create an epoch [numeric]

overlapping

The number of block which should overlap, and remain blank if overlapping should not be utilized numeric

output

Select the output which has to be either one row per 'period' or 'epoch'. [boolian]

Value

Returns a dataframe with the results, with either every period or epoch as a rows, depending on the chosen output

Examples

Run this code
# NOT RUN {
data <- data.frame(time=seq(1, 901, 0.01),
                  pres=rnorm(90001),
                  mcav=rnorm(90001))
Sx(df=data, freq=1000)
# }

Run the code above in your browser using DataLab