Raw recording with data in 3 columns: time (in seconds), arterial blood pressure curve measurement (ABP, raw measurement), and intracranial pressure curve measurement (ICP, raw measurement).
[dataframe]
del_1
Deleter with two columns, reference to arterial blood pressure curve measurement: (1) start of deletion period and (2) end of deletion period.
Every row is a deletion period. [dataframe]
del_2
Deleter with two columns, reference to intracranial pressure curve measurement: (1) start of deletion period and (2) end of deletion period.
Every row is a deletion period. [dataframe]
trigger
Trigger with two columns: (1) start of analysed period and (2) end of analysed period.
Every row is a period for analysis. [dataframe]
blocksize
Size of blocks, in seconds. [numeric]
epochsize
Size of epochs, in number of blocks. [numeric]
freq
Frequency of recorded data, in Hz. [numeric]
blockmin
Minimum measurements required to create a block [numeric]
epochmin
Minimum blocks required to create an epoch [numeric]
overlapping
The number of block which should overlap, and remain blank if overlapping should not be utilized numeric
output
Select the output which has to be either one row per 'period' or 'epoch'. [boolian]
Value
Returns a dataframe with the results, with either every period or epoch as a rows, depending on the chosen output